@@ -5,7 +5,7 @@ def main():
 
     ### SYSTEM SPECIFIC ###
 
-    ps_dir = os.path.dirname(__file__)+"/../pseudos/"  # Directory in which PBE_ONCV, PBESOL_ONCV, LDA_ONCV dirs are present
+    ps_dir = os.path.dirname(__file__)+"./pseudos/"  # Directory in which PBE_ONCV, PBESOL_ONCV, LDA_ONCV dirs are present
 
     parallel = 'mpirun'
     b = sorted(os.environ["PATH"].split(":"))
